# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PipelineArgs', 'Pipeline']

@pulumi.input_type
class PipelineArgs:
    def __init__(__self__, *,
                 contents: pulumi.Input[str],
                 enabled: Optional[pulumi.Input[bool]] = None,
                 matchers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Pipeline resource.
        :param pulumi.Input[str] contents: Configuration contents of the pipeline to be used by collectors
        :param pulumi.Input[bool] enabled: Whether the pipeline is enabled for collectors
        :param pulumi.Input[Sequence[pulumi.Input[str]]] matchers: Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        :param pulumi.Input[str] name: Name of the pipeline which is the unique identifier for the pipeline
        """
        pulumi.set(__self__, "contents", contents)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if matchers is not None:
            pulumi.set(__self__, "matchers", matchers)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def contents(self) -> pulumi.Input[str]:
        """
        Configuration contents of the pipeline to be used by collectors
        """
        return pulumi.get(self, "contents")

    @contents.setter
    def contents(self, value: pulumi.Input[str]):
        pulumi.set(self, "contents", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the pipeline is enabled for collectors
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def matchers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        """
        return pulumi.get(self, "matchers")

    @matchers.setter
    def matchers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "matchers", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the pipeline which is the unique identifier for the pipeline
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PipelineState:
    def __init__(__self__, *,
                 contents: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 matchers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Pipeline resources.
        :param pulumi.Input[str] contents: Configuration contents of the pipeline to be used by collectors
        :param pulumi.Input[bool] enabled: Whether the pipeline is enabled for collectors
        :param pulumi.Input[Sequence[pulumi.Input[str]]] matchers: Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        :param pulumi.Input[str] name: Name of the pipeline which is the unique identifier for the pipeline
        """
        if contents is not None:
            pulumi.set(__self__, "contents", contents)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if matchers is not None:
            pulumi.set(__self__, "matchers", matchers)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def contents(self) -> Optional[pulumi.Input[str]]:
        """
        Configuration contents of the pipeline to be used by collectors
        """
        return pulumi.get(self, "contents")

    @contents.setter
    def contents(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "contents", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the pipeline is enabled for collectors
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def matchers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        """
        return pulumi.get(self, "matchers")

    @matchers.setter
    def matchers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "matchers", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the pipeline which is the unique identifier for the pipeline
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Pipeline(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contents: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 matchers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages Grafana Fleet Management pipelines.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/pipeline-api/)

        Required access policy scopes:

        * fleet-management:read
        * fleet-management:write

        ## Import

        ```sh
        $ pulumi import grafana:fleetManagement/pipeline:Pipeline name "{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] contents: Configuration contents of the pipeline to be used by collectors
        :param pulumi.Input[bool] enabled: Whether the pipeline is enabled for collectors
        :param pulumi.Input[Sequence[pulumi.Input[str]]] matchers: Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        :param pulumi.Input[str] name: Name of the pipeline which is the unique identifier for the pipeline
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana Fleet Management pipelines.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/pipeline-api/)

        Required access policy scopes:

        * fleet-management:read
        * fleet-management:write

        ## Import

        ```sh
        $ pulumi import grafana:fleetManagement/pipeline:Pipeline name "{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param PipelineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contents: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 matchers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineArgs.__new__(PipelineArgs)

            if contents is None and not opts.urn:
                raise TypeError("Missing required property 'contents'")
            __props__.__dict__["contents"] = contents
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["matchers"] = matchers
            __props__.__dict__["name"] = name
        super(Pipeline, __self__).__init__(
            'grafana:fleetManagement/pipeline:Pipeline',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            contents: Optional[pulumi.Input[str]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            matchers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Pipeline':
        """
        Get an existing Pipeline resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] contents: Configuration contents of the pipeline to be used by collectors
        :param pulumi.Input[bool] enabled: Whether the pipeline is enabled for collectors
        :param pulumi.Input[Sequence[pulumi.Input[str]]] matchers: Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        :param pulumi.Input[str] name: Name of the pipeline which is the unique identifier for the pipeline
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineState.__new__(_PipelineState)

        __props__.__dict__["contents"] = contents
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["matchers"] = matchers
        __props__.__dict__["name"] = name
        return Pipeline(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def contents(self) -> pulumi.Output[str]:
        """
        Configuration contents of the pipeline to be used by collectors
        """
        return pulumi.get(self, "contents")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        """
        Whether the pipeline is enabled for collectors
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def matchers(self) -> pulumi.Output[Sequence[str]]:
        """
        Used to match against collectors and assign pipelines to them; follows the syntax of Prometheus Alertmanager matchers
        """
        return pulumi.get(self, "matchers")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the pipeline which is the unique identifier for the pipeline
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('grafana')


class _ExportableConfig(types.ModuleType):
    @property
    def auth(self) -> Optional[str]:
        """
        API token, basic auth in the `username:password` format or `anonymous` (string literal). May alternatively be set via
        the `GRAFANA_AUTH` environment variable.
        """
        return __config__.get('auth') or _utilities.get_env('GRAFANA_AUTH')

    @property
    def ca_cert(self) -> Optional[str]:
        """
        Certificate CA bundle (file path or literal value) to use to verify the Grafana server's certificate. May alternatively
        be set via the `GRAFANA_CA_CERT` environment variable.
        """
        return __config__.get('caCert') or _utilities.get_env('GRAFANA_CA_CERT')

    @property
    def cloud_access_policy_token(self) -> Optional[str]:
        """
        Access Policy Token for Grafana Cloud. May alternatively be set via the `GRAFANA_CLOUD_ACCESS_POLICY_TOKEN` environment
        variable.
        """
        return __config__.get('cloudAccessPolicyToken') or _utilities.get_env('GRAFANA_CLOUD_ACCESS_POLICY_TOKEN')

    @property
    def cloud_api_url(self) -> Optional[str]:
        """
        Grafana Cloud's API URL. May alternatively be set via the `GRAFANA_CLOUD_API_URL` environment variable.
        """
        return __config__.get('cloudApiUrl') or _utilities.get_env('GRAFANA_CLOUD_API_URL')

    @property
    def cloud_provider_access_token(self) -> Optional[str]:
        """
        A Grafana Cloud Provider access token. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_ACCESS_TOKEN`
        environment variable.
        """
        return __config__.get('cloudProviderAccessToken')

    @property
    def cloud_provider_url(self) -> Optional[str]:
        """
        A Grafana Cloud Provider backend address. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_URL` environment
        variable.
        """
        return __config__.get('cloudProviderUrl')

    @property
    def connections_api_access_token(self) -> Optional[str]:
        """
        A Grafana Connections API access token. May alternatively be set via the `GRAFANA_CONNECTIONS_API_ACCESS_TOKEN`
        environment variable.
        """
        return __config__.get('connectionsApiAccessToken')

    @property
    def connections_api_url(self) -> Optional[str]:
        """
        A Grafana Connections API address. May alternatively be set via the `GRAFANA_CONNECTIONS_API_URL` environment variable.
        """
        return __config__.get('connectionsApiUrl')

    @property
    def fleet_management_auth(self) -> Optional[str]:
        """
        A Grafana Fleet Management basic auth in the `username:password` format. May alternatively be set via the
        `GRAFANA_FLEET_MANAGEMENT_AUTH` environment variable.
        """
        return __config__.get('fleetManagementAuth')

    @property
    def fleet_management_url(self) -> Optional[str]:
        """
        A Grafana Fleet Management API address. May alternatively be set via the `GRAFANA_FLEET_MANAGEMENT_URL` environment
        variable.
        """
        return __config__.get('fleetManagementUrl')

    @property
    def frontend_o11y_api_access_token(self) -> Optional[str]:
        """
        A Grafana Frontend Observability API access token. May alternatively be set via the
        `GRAFANA_FRONTEND_O11Y_API_ACCESS_TOKEN` environment variable.
        """
        return __config__.get('frontendO11yApiAccessToken')

    @property
    def http_headers(self) -> Optional[str]:
        """
        Optional. HTTP headers mapping keys to values used for accessing the Grafana and Grafana Cloud APIs. May alternatively
        be set via the `GRAFANA_HTTP_HEADERS` environment variable in JSON format.
        """
        return __config__.get('httpHeaders')

    @property
    def insecure_skip_verify(self) -> Optional[bool]:
        """
        Skip TLS certificate verification. May alternatively be set via the `GRAFANA_INSECURE_SKIP_VERIFY` environment variable.
        """
        return __config__.get_bool('insecureSkipVerify') or _utilities.get_env_bool('GRAFANA_INSECURE_SKIP_VERIFY')

    @property
    def oncall_access_token(self) -> Optional[str]:
        """
        A Grafana OnCall access token. May alternatively be set via the `GRAFANA_ONCALL_ACCESS_TOKEN` environment variable.
        """
        return __config__.get('oncallAccessToken') or _utilities.get_env('GRAFANA_ONCALL_ACCESS_TOKEN')

    @property
    def oncall_url(self) -> Optional[str]:
        """
        An Grafana OnCall backend address. May alternatively be set via the `GRAFANA_ONCALL_URL` environment variable.
        """
        return __config__.get('oncallUrl') or _utilities.get_env('GRAFANA_ONCALL_URL')

    @property
    def retries(self) -> Optional[int]:
        """
        The amount of retries to use for Grafana API and Grafana Cloud API calls. May alternatively be set via the
        `GRAFANA_RETRIES` environment variable.
        """
        return __config__.get_int('retries') or _utilities.get_env_int('GRAFANA_RETRIES')

    @property
    def retry_status_codes(self) -> Optional[str]:
        """
        The status codes to retry on for Grafana API and Grafana Cloud API calls. Use `x` as a digit wildcard. Defaults to 429
        and 5xx. May alternatively be set via the `GRAFANA_RETRY_STATUS_CODES` environment variable.
        """
        return __config__.get('retryStatusCodes')

    @property
    def retry_wait(self) -> Optional[int]:
        """
        The amount of time in seconds to wait between retries for Grafana API and Grafana Cloud API calls. May alternatively be
        set via the `GRAFANA_RETRY_WAIT` environment variable.
        """
        return __config__.get_int('retryWait') or _utilities.get_env_int('GRAFANA_RETRY_WAIT')

    @property
    def sm_access_token(self) -> Optional[str]:
        """
        A Synthetic Monitoring access token. May alternatively be set via the `GRAFANA_SM_ACCESS_TOKEN` environment variable.
        """
        return __config__.get('smAccessToken') or _utilities.get_env('GRAFANA_SM_ACCESS_TOKEN')

    @property
    def sm_url(self) -> Optional[str]:
        return __config__.get('smUrl') or _utilities.get_env('GRAFANA_SM_URL')

    @property
    def store_dashboard_sha256(self) -> Optional[bool]:
        """
        Set to true if you want to save only the sha256sum instead of complete dashboard model JSON in the tfstate.
        """
        return __config__.get_bool('storeDashboardSha256') or _utilities.get_env_bool('GRAFANA_STORE_DASHBOARD_SHA256')

    @property
    def tls_cert(self) -> Optional[str]:
        """
        Client TLS certificate (file path or literal value) to use to authenticate to the Grafana server. May alternatively be
        set via the `GRAFANA_TLS_CERT` environment variable.
        """
        return __config__.get('tlsCert') or _utilities.get_env('GRAFANA_TLS_CERT')

    @property
    def tls_key(self) -> Optional[str]:
        """
        Client TLS key (file path or literal value) to use to authenticate to the Grafana server. May alternatively be set via
        the `GRAFANA_TLS_KEY` environment variable.
        """
        return __config__.get('tlsKey') or _utilities.get_env('GRAFANA_TLS_KEY')

    @property
    def url(self) -> Optional[str]:
        """
        The root URL of a Grafana server. May alternatively be set via the `GRAFANA_URL` environment variable.
        """
        return __config__.get('url') or _utilities.get_env('GRAFANA_URL')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLibraryPanelsResult',
    'AwaitableGetLibraryPanelsResult',
    'get_library_panels',
    'get_library_panels_output',
]

@pulumi.output_type
class GetLibraryPanelsResult:
    """
    A collection of values returned by getLibraryPanels.
    """
    def __init__(__self__, id=None, org_id=None, panels=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if panels and not isinstance(panels, list):
            raise TypeError("Expected argument 'panels' to be a list")
        pulumi.set(__self__, "panels", panels)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def panels(self) -> Sequence['outputs.GetLibraryPanelsPanelResult']:
        return pulumi.get(self, "panels")


class AwaitableGetLibraryPanelsResult(GetLibraryPanelsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLibraryPanelsResult(
            id=self.id,
            org_id=self.org_id,
            panels=self.panels)


def get_library_panels(org_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLibraryPanelsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.oss.LibraryPanel("test",
        name="panelname",
        model_json=json.dumps({
            "title": "test name",
            "type": "text",
            "version": 0,
            "description": "test description",
        }))
    test_folder = grafana.oss.Folder("test",
        title="Panel Folder",
        uid="panelname-folder")
    folder = grafana.oss.LibraryPanel("folder",
        name="panelname In Folder",
        folder_uid=test_folder.uid,
        model_json=json.dumps({
            "gridPos": {
                "x": 0,
                "y": 0,
                "h": 10,
                "w": 10,
            },
            "title": "panel",
            "type": "text",
            "version": 0,
        }))
    all = grafana.oss.get_library_panels()
    ```


    :param str org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
    """
    __args__ = dict()
    __args__['orgId'] = org_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:oss/getLibraryPanels:getLibraryPanels', __args__, opts=opts, typ=GetLibraryPanelsResult).value

    return AwaitableGetLibraryPanelsResult(
        id=pulumi.get(__ret__, 'id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        panels=pulumi.get(__ret__, 'panels'))
def get_library_panels_output(org_id: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLibraryPanelsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.oss.LibraryPanel("test",
        name="panelname",
        model_json=json.dumps({
            "title": "test name",
            "type": "text",
            "version": 0,
            "description": "test description",
        }))
    test_folder = grafana.oss.Folder("test",
        title="Panel Folder",
        uid="panelname-folder")
    folder = grafana.oss.LibraryPanel("folder",
        name="panelname In Folder",
        folder_uid=test_folder.uid,
        model_json=json.dumps({
            "gridPos": {
                "x": 0,
                "y": 0,
                "h": 10,
                "w": 10,
            },
            "title": "panel",
            "type": "text",
            "version": 0,
        }))
    all = grafana.oss.get_library_panels()
    ```


    :param str org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
    """
    __args__ = dict()
    __args__['orgId'] = org_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:oss/getLibraryPanels:getLibraryPanels', __args__, opts=opts, typ=GetLibraryPanelsResult)
    return __ret__.apply(lambda __response__: GetLibraryPanelsResult(
        id=pulumi.get(__response__, 'id'),
        org_id=pulumi.get(__response__, 'org_id'),
        panels=pulumi.get(__response__, 'panels')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DataSourceArgs', 'DataSource']

@pulumi.input_type
class DataSourceArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 access_mode: Optional[pulumi.Input[str]] = None,
                 basic_auth_enabled: Optional[pulumi.Input[bool]] = None,
                 basic_auth_username: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 json_data_encoded: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 private_data_source_connect_network_id: Optional[pulumi.Input[str]] = None,
                 secure_json_data_encoded: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DataSource resource.
        :param pulumi.Input[str] type: The data source type. Must be one of the supported data source keywords.
        :param pulumi.Input[str] access_mode: The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        :param pulumi.Input[bool] basic_auth_enabled: Whether to enable basic auth for the data source. Defaults to `false`.
        :param pulumi.Input[str] basic_auth_username: Basic auth username. Defaults to ``.
        :param pulumi.Input[str] database_name: (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] http_headers: Custom HTTP headers
        :param pulumi.Input[bool] is_default: Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        :param pulumi.Input[str] json_data_encoded: Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] name: A unique name for the data source.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] private_data_source_connect_network_id: (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        :param pulumi.Input[str] secure_json_data_encoded: Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] uid: Unique identifier. If unset, this will be automatically generated.
        :param pulumi.Input[str] url: The URL for the data source. The type of URL required varies depending on the chosen data source type.
        :param pulumi.Input[str] username: (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        pulumi.set(__self__, "type", type)
        if access_mode is not None:
            pulumi.set(__self__, "access_mode", access_mode)
        if basic_auth_enabled is not None:
            pulumi.set(__self__, "basic_auth_enabled", basic_auth_enabled)
        if basic_auth_username is not None:
            pulumi.set(__self__, "basic_auth_username", basic_auth_username)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if http_headers is not None:
            pulumi.set(__self__, "http_headers", http_headers)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if json_data_encoded is not None:
            pulumi.set(__self__, "json_data_encoded", json_data_encoded)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if private_data_source_connect_network_id is not None:
            pulumi.set(__self__, "private_data_source_connect_network_id", private_data_source_connect_network_id)
        if secure_json_data_encoded is not None:
            pulumi.set(__self__, "secure_json_data_encoded", secure_json_data_encoded)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The data source type. Must be one of the supported data source keywords.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        """
        return pulumi.get(self, "access_mode")

    @access_mode.setter
    def access_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_mode", value)

    @property
    @pulumi.getter(name="basicAuthEnabled")
    def basic_auth_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable basic auth for the data source. Defaults to `false`.
        """
        return pulumi.get(self, "basic_auth_enabled")

    @basic_auth_enabled.setter
    def basic_auth_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "basic_auth_enabled", value)

    @property
    @pulumi.getter(name="basicAuthUsername")
    def basic_auth_username(self) -> Optional[pulumi.Input[str]]:
        """
        Basic auth username. Defaults to ``.
        """
        return pulumi.get(self, "basic_auth_username")

    @basic_auth_username.setter
    def basic_auth_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "basic_auth_username", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Custom HTTP headers
        """
        return pulumi.get(self, "http_headers")

    @http_headers.setter
    def http_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "http_headers", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="jsonDataEncoded")
    def json_data_encoded(self) -> Optional[pulumi.Input[str]]:
        """
        Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "json_data_encoded")

    @json_data_encoded.setter
    def json_data_encoded(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "json_data_encoded", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A unique name for the data source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="privateDataSourceConnectNetworkId")
    def private_data_source_connect_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        """
        return pulumi.get(self, "private_data_source_connect_network_id")

    @private_data_source_connect_network_id.setter
    def private_data_source_connect_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_data_source_connect_network_id", value)

    @property
    @pulumi.getter(name="secureJsonDataEncoded")
    def secure_json_data_encoded(self) -> Optional[pulumi.Input[str]]:
        """
        Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "secure_json_data_encoded")

    @secure_json_data_encoded.setter
    def secure_json_data_encoded(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secure_json_data_encoded", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier. If unset, this will be automatically generated.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL for the data source. The type of URL required varies depending on the chosen data source type.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _DataSourceState:
    def __init__(__self__, *,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 basic_auth_enabled: Optional[pulumi.Input[bool]] = None,
                 basic_auth_username: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 json_data_encoded: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 private_data_source_connect_network_id: Optional[pulumi.Input[str]] = None,
                 secure_json_data_encoded: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DataSource resources.
        :param pulumi.Input[str] access_mode: The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        :param pulumi.Input[bool] basic_auth_enabled: Whether to enable basic auth for the data source. Defaults to `false`.
        :param pulumi.Input[str] basic_auth_username: Basic auth username. Defaults to ``.
        :param pulumi.Input[str] database_name: (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] http_headers: Custom HTTP headers
        :param pulumi.Input[bool] is_default: Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        :param pulumi.Input[str] json_data_encoded: Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] name: A unique name for the data source.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] private_data_source_connect_network_id: (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        :param pulumi.Input[str] secure_json_data_encoded: Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] type: The data source type. Must be one of the supported data source keywords.
        :param pulumi.Input[str] uid: Unique identifier. If unset, this will be automatically generated.
        :param pulumi.Input[str] url: The URL for the data source. The type of URL required varies depending on the chosen data source type.
        :param pulumi.Input[str] username: (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        if access_mode is not None:
            pulumi.set(__self__, "access_mode", access_mode)
        if basic_auth_enabled is not None:
            pulumi.set(__self__, "basic_auth_enabled", basic_auth_enabled)
        if basic_auth_username is not None:
            pulumi.set(__self__, "basic_auth_username", basic_auth_username)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if http_headers is not None:
            pulumi.set(__self__, "http_headers", http_headers)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if json_data_encoded is not None:
            pulumi.set(__self__, "json_data_encoded", json_data_encoded)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if private_data_source_connect_network_id is not None:
            pulumi.set(__self__, "private_data_source_connect_network_id", private_data_source_connect_network_id)
        if secure_json_data_encoded is not None:
            pulumi.set(__self__, "secure_json_data_encoded", secure_json_data_encoded)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        """
        return pulumi.get(self, "access_mode")

    @access_mode.setter
    def access_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_mode", value)

    @property
    @pulumi.getter(name="basicAuthEnabled")
    def basic_auth_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable basic auth for the data source. Defaults to `false`.
        """
        return pulumi.get(self, "basic_auth_enabled")

    @basic_auth_enabled.setter
    def basic_auth_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "basic_auth_enabled", value)

    @property
    @pulumi.getter(name="basicAuthUsername")
    def basic_auth_username(self) -> Optional[pulumi.Input[str]]:
        """
        Basic auth username. Defaults to ``.
        """
        return pulumi.get(self, "basic_auth_username")

    @basic_auth_username.setter
    def basic_auth_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "basic_auth_username", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Custom HTTP headers
        """
        return pulumi.get(self, "http_headers")

    @http_headers.setter
    def http_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "http_headers", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="jsonDataEncoded")
    def json_data_encoded(self) -> Optional[pulumi.Input[str]]:
        """
        Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "json_data_encoded")

    @json_data_encoded.setter
    def json_data_encoded(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "json_data_encoded", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A unique name for the data source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="privateDataSourceConnectNetworkId")
    def private_data_source_connect_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        """
        return pulumi.get(self, "private_data_source_connect_network_id")

    @private_data_source_connect_network_id.setter
    def private_data_source_connect_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_data_source_connect_network_id", value)

    @property
    @pulumi.getter(name="secureJsonDataEncoded")
    def secure_json_data_encoded(self) -> Optional[pulumi.Input[str]]:
        """
        Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "secure_json_data_encoded")

    @secure_json_data_encoded.setter
    def secure_json_data_encoded(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secure_json_data_encoded", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The data source type. Must be one of the supported data source keywords.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier. If unset, this will be automatically generated.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL for the data source. The type of URL required varies depending on the chosen data source type.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


warnings.warn("""grafana.index/datasource.DataSource has been deprecated in favor of grafana.oss/datasource.DataSource""", DeprecationWarning)


class DataSource(pulumi.CustomResource):
    warnings.warn("""grafana.index/datasource.DataSource has been deprecated in favor of grafana.oss/datasource.DataSource""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 basic_auth_enabled: Optional[pulumi.Input[bool]] = None,
                 basic_auth_username: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 json_data_encoded: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 private_data_source_connect_network_id: Optional[pulumi.Input[str]] = None,
                 secure_json_data_encoded: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/datasources/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/data_source/)

        The required arguments for this resource vary depending on the type of data
        source selected (via the 'type' argument).

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        arbitrary_data = grafana.oss.DataSource("arbitrary-data",
            type="stackdriver",
            name="sd-arbitrary-data",
            json_data_encoded=json.dumps({
                "tokenUri": "https://oauth2.googleapis.com/token",
                "authenticationType": "jwt",
                "defaultProject": "default-project",
                "clientEmail": "client-email@default-project.iam.gserviceaccount.com",
            }),
            secure_json_data_encoded=json.dumps({
                "privateKey": \"\"\"-----BEGIN PRIVATE KEY-----
        private-key
        -----END PRIVATE KEY-----
        \"\"\",
            }))
        influxdb = grafana.oss.DataSource("influxdb",
            type="influxdb",
            name="myapp-metrics",
            url="http://influxdb.example.net:8086/",
            basic_auth_enabled=True,
            basic_auth_username="username",
            database_name="dbname",
            json_data_encoded=json.dumps({
                "authType": "default",
                "basicAuthPassword": "mypassword",
            }))
        cloudwatch = grafana.oss.DataSource("cloudwatch",
            type="cloudwatch",
            name="cw-example",
            json_data_encoded=json.dumps({
                "defaultRegion": "us-east-1",
                "authType": "keys",
            }),
            secure_json_data_encoded=json.dumps({
                "accessKey": "123",
                "secretKey": "456",
            }))
        cloudwatch_assume_arn = grafana.oss.DataSource("cloudwatch_assumeARN",
            type="cloudwatch",
            name="cw-assumeARN-example",
            json_data_encoded=json.dumps({
                "defaultRegion": "us-east-1",
                "authType": "grafana_assume_role",
                "assumeRoleArn": "arn:aws:iam::123456789012:root",
            }))
        prometheus = grafana.oss.DataSource("prometheus",
            type="prometheus",
            name="mimir",
            url="https://my-instances.com",
            basic_auth_enabled=True,
            basic_auth_username="username",
            json_data_encoded=json.dumps({
                "httpMethod": "POST",
                "prometheusType": "Mimir",
                "prometheusVersion": "2.4.0",
            }),
            secure_json_data_encoded=json.dumps({
                "basicAuthPassword": "password",
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dataSource:DataSource name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/dataSource:DataSource name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        :param pulumi.Input[bool] basic_auth_enabled: Whether to enable basic auth for the data source. Defaults to `false`.
        :param pulumi.Input[str] basic_auth_username: Basic auth username. Defaults to ``.
        :param pulumi.Input[str] database_name: (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] http_headers: Custom HTTP headers
        :param pulumi.Input[bool] is_default: Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        :param pulumi.Input[str] json_data_encoded: Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] name: A unique name for the data source.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] private_data_source_connect_network_id: (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        :param pulumi.Input[str] secure_json_data_encoded: Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] type: The data source type. Must be one of the supported data source keywords.
        :param pulumi.Input[str] uid: Unique identifier. If unset, this will be automatically generated.
        :param pulumi.Input[str] url: The URL for the data source. The type of URL required varies depending on the chosen data source type.
        :param pulumi.Input[str] username: (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/datasources/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/data_source/)

        The required arguments for this resource vary depending on the type of data
        source selected (via the 'type' argument).

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        arbitrary_data = grafana.oss.DataSource("arbitrary-data",
            type="stackdriver",
            name="sd-arbitrary-data",
            json_data_encoded=json.dumps({
                "tokenUri": "https://oauth2.googleapis.com/token",
                "authenticationType": "jwt",
                "defaultProject": "default-project",
                "clientEmail": "client-email@default-project.iam.gserviceaccount.com",
            }),
            secure_json_data_encoded=json.dumps({
                "privateKey": \"\"\"-----BEGIN PRIVATE KEY-----
        private-key
        -----END PRIVATE KEY-----
        \"\"\",
            }))
        influxdb = grafana.oss.DataSource("influxdb",
            type="influxdb",
            name="myapp-metrics",
            url="http://influxdb.example.net:8086/",
            basic_auth_enabled=True,
            basic_auth_username="username",
            database_name="dbname",
            json_data_encoded=json.dumps({
                "authType": "default",
                "basicAuthPassword": "mypassword",
            }))
        cloudwatch = grafana.oss.DataSource("cloudwatch",
            type="cloudwatch",
            name="cw-example",
            json_data_encoded=json.dumps({
                "defaultRegion": "us-east-1",
                "authType": "keys",
            }),
            secure_json_data_encoded=json.dumps({
                "accessKey": "123",
                "secretKey": "456",
            }))
        cloudwatch_assume_arn = grafana.oss.DataSource("cloudwatch_assumeARN",
            type="cloudwatch",
            name="cw-assumeARN-example",
            json_data_encoded=json.dumps({
                "defaultRegion": "us-east-1",
                "authType": "grafana_assume_role",
                "assumeRoleArn": "arn:aws:iam::123456789012:root",
            }))
        prometheus = grafana.oss.DataSource("prometheus",
            type="prometheus",
            name="mimir",
            url="https://my-instances.com",
            basic_auth_enabled=True,
            basic_auth_username="username",
            json_data_encoded=json.dumps({
                "httpMethod": "POST",
                "prometheusType": "Mimir",
                "prometheusVersion": "2.4.0",
            }),
            secure_json_data_encoded=json.dumps({
                "basicAuthPassword": "password",
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dataSource:DataSource name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/dataSource:DataSource name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param DataSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 basic_auth_enabled: Optional[pulumi.Input[bool]] = None,
                 basic_auth_username: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 is_default: Optional[pulumi.Input[bool]] = None,
                 json_data_encoded: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 private_data_source_connect_network_id: Optional[pulumi.Input[str]] = None,
                 secure_json_data_encoded: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""DataSource is deprecated: grafana.index/datasource.DataSource has been deprecated in favor of grafana.oss/datasource.DataSource""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataSourceArgs.__new__(DataSourceArgs)

            __props__.__dict__["access_mode"] = access_mode
            __props__.__dict__["basic_auth_enabled"] = basic_auth_enabled
            __props__.__dict__["basic_auth_username"] = basic_auth_username
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["http_headers"] = None if http_headers is None else pulumi.Output.secret(http_headers)
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["json_data_encoded"] = json_data_encoded
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["private_data_source_connect_network_id"] = private_data_source_connect_network_id
            __props__.__dict__["secure_json_data_encoded"] = None if secure_json_data_encoded is None else pulumi.Output.secret(secure_json_data_encoded)
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["uid"] = uid
            __props__.__dict__["url"] = url
            __props__.__dict__["username"] = username
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/dataSource:DataSource")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["httpHeaders", "secureJsonDataEncoded"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DataSource, __self__).__init__(
            'grafana:index/dataSource:DataSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_mode: Optional[pulumi.Input[str]] = None,
            basic_auth_enabled: Optional[pulumi.Input[bool]] = None,
            basic_auth_username: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            is_default: Optional[pulumi.Input[bool]] = None,
            json_data_encoded: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            private_data_source_connect_network_id: Optional[pulumi.Input[str]] = None,
            secure_json_data_encoded: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            uid: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'DataSource':
        """
        Get an existing DataSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        :param pulumi.Input[bool] basic_auth_enabled: Whether to enable basic auth for the data source. Defaults to `false`.
        :param pulumi.Input[str] basic_auth_username: Basic auth username. Defaults to ``.
        :param pulumi.Input[str] database_name: (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] http_headers: Custom HTTP headers
        :param pulumi.Input[bool] is_default: Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        :param pulumi.Input[str] json_data_encoded: Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] name: A unique name for the data source.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] private_data_source_connect_network_id: (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        :param pulumi.Input[str] secure_json_data_encoded: Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        :param pulumi.Input[str] type: The data source type. Must be one of the supported data source keywords.
        :param pulumi.Input[str] uid: Unique identifier. If unset, this will be automatically generated.
        :param pulumi.Input[str] url: The URL for the data source. The type of URL required varies depending on the chosen data source type.
        :param pulumi.Input[str] username: (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataSourceState.__new__(_DataSourceState)

        __props__.__dict__["access_mode"] = access_mode
        __props__.__dict__["basic_auth_enabled"] = basic_auth_enabled
        __props__.__dict__["basic_auth_username"] = basic_auth_username
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["http_headers"] = http_headers
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["json_data_encoded"] = json_data_encoded
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["private_data_source_connect_network_id"] = private_data_source_connect_network_id
        __props__.__dict__["secure_json_data_encoded"] = secure_json_data_encoded
        __props__.__dict__["type"] = type
        __props__.__dict__["uid"] = uid
        __props__.__dict__["url"] = url
        __props__.__dict__["username"] = username
        return DataSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The method by which Grafana will access the data source: `proxy` or `direct`. Defaults to `proxy`.
        """
        return pulumi.get(self, "access_mode")

    @property
    @pulumi.getter(name="basicAuthEnabled")
    def basic_auth_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to enable basic auth for the data source. Defaults to `false`.
        """
        return pulumi.get(self, "basic_auth_enabled")

    @property
    @pulumi.getter(name="basicAuthUsername")
    def basic_auth_username(self) -> pulumi.Output[Optional[str]]:
        """
        Basic auth username. Defaults to ``.
        """
        return pulumi.get(self, "basic_auth_username")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        (Required by some data source types) The name of the database to use on the selected data source server. Defaults to ``.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Custom HTTP headers
        """
        return pulumi.get(self, "http_headers")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to set the data source as default. This should only be `true` to a single data source. Defaults to `false`.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="jsonDataEncoded")
    def json_data_encoded(self) -> pulumi.Output[Optional[str]]:
        """
        Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "json_data_encoded")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A unique name for the data source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="privateDataSourceConnectNetworkId")
    def private_data_source_connect_network_id(self) -> pulumi.Output[Optional[str]]:
        """
        (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source. Defaults to ``.
        """
        return pulumi.get(self, "private_data_source_connect_network_id")

    @property
    @pulumi.getter(name="secureJsonDataEncoded")
    def secure_json_data_encoded(self) -> pulumi.Output[Optional[str]]:
        """
        Serialized JSON string containing the secure json data. This attribute can be used to pass secure configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "secure_json_data_encoded")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The data source type. Must be one of the supported data source keywords.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[str]:
        """
        Unique identifier. If unset, this will be automatically generated.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[Optional[str]]:
        """
        The URL for the data source. The type of URL required varies depending on the chosen data source type.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        (Required by some data source types) The username to use to authenticate to the data source. Defaults to ``.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ScheduleArgs', 'Schedule']

@pulumi.input_type
class ScheduleArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 enable_web_overrides: Optional[pulumi.Input[bool]] = None,
                 ical_url_overrides: Optional[pulumi.Input[str]] = None,
                 ical_url_primary: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 shifts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 slack: Optional[pulumi.Input['ScheduleSlackArgs']] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 time_zone: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Schedule resource.
        :param pulumi.Input[str] type: The schedule's type. Valid values are `ical`, `calendar`.
        :param pulumi.Input[bool] enable_web_overrides: Enable overrides via web UI (it will ignore ical*url*overrides).
        :param pulumi.Input[str] ical_url_overrides: The URL of external iCal calendar which override primary events.
        :param pulumi.Input[str] ical_url_primary: The URL of the external calendar iCal file.
        :param pulumi.Input[str] name: The schedule's name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] shifts: The list of ID's of on-call shifts.
        :param pulumi.Input['ScheduleSlackArgs'] slack: The Slack-specific settings for a schedule.
        :param pulumi.Input[str] team_id: The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        :param pulumi.Input[str] time_zone: The schedule's time zone.
        """
        pulumi.set(__self__, "type", type)
        if enable_web_overrides is not None:
            pulumi.set(__self__, "enable_web_overrides", enable_web_overrides)
        if ical_url_overrides is not None:
            pulumi.set(__self__, "ical_url_overrides", ical_url_overrides)
        if ical_url_primary is not None:
            pulumi.set(__self__, "ical_url_primary", ical_url_primary)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if shifts is not None:
            pulumi.set(__self__, "shifts", shifts)
        if slack is not None:
            pulumi.set(__self__, "slack", slack)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The schedule's type. Valid values are `ical`, `calendar`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="enableWebOverrides")
    def enable_web_overrides(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable overrides via web UI (it will ignore ical*url*overrides).
        """
        return pulumi.get(self, "enable_web_overrides")

    @enable_web_overrides.setter
    def enable_web_overrides(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_web_overrides", value)

    @property
    @pulumi.getter(name="icalUrlOverrides")
    def ical_url_overrides(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of external iCal calendar which override primary events.
        """
        return pulumi.get(self, "ical_url_overrides")

    @ical_url_overrides.setter
    def ical_url_overrides(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ical_url_overrides", value)

    @property
    @pulumi.getter(name="icalUrlPrimary")
    def ical_url_primary(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of the external calendar iCal file.
        """
        return pulumi.get(self, "ical_url_primary")

    @ical_url_primary.setter
    def ical_url_primary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ical_url_primary", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The schedule's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def shifts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of on-call shifts.
        """
        return pulumi.get(self, "shifts")

    @shifts.setter
    def shifts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "shifts", value)

    @property
    @pulumi.getter
    def slack(self) -> Optional[pulumi.Input['ScheduleSlackArgs']]:
        """
        The Slack-specific settings for a schedule.
        """
        return pulumi.get(self, "slack")

    @slack.setter
    def slack(self, value: Optional[pulumi.Input['ScheduleSlackArgs']]):
        pulumi.set(self, "slack", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[str]]:
        """
        The schedule's time zone.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_zone", value)


@pulumi.input_type
class _ScheduleState:
    def __init__(__self__, *,
                 enable_web_overrides: Optional[pulumi.Input[bool]] = None,
                 ical_url_overrides: Optional[pulumi.Input[str]] = None,
                 ical_url_primary: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 shifts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 slack: Optional[pulumi.Input['ScheduleSlackArgs']] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 time_zone: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Schedule resources.
        :param pulumi.Input[bool] enable_web_overrides: Enable overrides via web UI (it will ignore ical*url*overrides).
        :param pulumi.Input[str] ical_url_overrides: The URL of external iCal calendar which override primary events.
        :param pulumi.Input[str] ical_url_primary: The URL of the external calendar iCal file.
        :param pulumi.Input[str] name: The schedule's name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] shifts: The list of ID's of on-call shifts.
        :param pulumi.Input['ScheduleSlackArgs'] slack: The Slack-specific settings for a schedule.
        :param pulumi.Input[str] team_id: The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        :param pulumi.Input[str] time_zone: The schedule's time zone.
        :param pulumi.Input[str] type: The schedule's type. Valid values are `ical`, `calendar`.
        """
        if enable_web_overrides is not None:
            pulumi.set(__self__, "enable_web_overrides", enable_web_overrides)
        if ical_url_overrides is not None:
            pulumi.set(__self__, "ical_url_overrides", ical_url_overrides)
        if ical_url_primary is not None:
            pulumi.set(__self__, "ical_url_primary", ical_url_primary)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if shifts is not None:
            pulumi.set(__self__, "shifts", shifts)
        if slack is not None:
            pulumi.set(__self__, "slack", slack)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="enableWebOverrides")
    def enable_web_overrides(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable overrides via web UI (it will ignore ical*url*overrides).
        """
        return pulumi.get(self, "enable_web_overrides")

    @enable_web_overrides.setter
    def enable_web_overrides(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_web_overrides", value)

    @property
    @pulumi.getter(name="icalUrlOverrides")
    def ical_url_overrides(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of external iCal calendar which override primary events.
        """
        return pulumi.get(self, "ical_url_overrides")

    @ical_url_overrides.setter
    def ical_url_overrides(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ical_url_overrides", value)

    @property
    @pulumi.getter(name="icalUrlPrimary")
    def ical_url_primary(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of the external calendar iCal file.
        """
        return pulumi.get(self, "ical_url_primary")

    @ical_url_primary.setter
    def ical_url_primary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ical_url_primary", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The schedule's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def shifts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of on-call shifts.
        """
        return pulumi.get(self, "shifts")

    @shifts.setter
    def shifts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "shifts", value)

    @property
    @pulumi.getter
    def slack(self) -> Optional[pulumi.Input['ScheduleSlackArgs']]:
        """
        The Slack-specific settings for a schedule.
        """
        return pulumi.get(self, "slack")

    @slack.setter
    def slack(self, value: Optional[pulumi.Input['ScheduleSlackArgs']]):
        pulumi.set(self, "slack", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[str]]:
        """
        The schedule's time zone.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_zone", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The schedule's type. Valid values are `ical`, `calendar`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class Schedule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_web_overrides: Optional[pulumi.Input[bool]] = None,
                 ical_url_overrides: Optional[pulumi.Input[str]] = None,
                 ical_url_primary: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 shifts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 slack: Optional[pulumi.Input[Union['ScheduleSlackArgs', 'ScheduleSlackArgsDict']]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 time_zone: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/schedules/)

        ## Import

        ```sh
        $ pulumi import grafana:onCall/schedule:Schedule name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_web_overrides: Enable overrides via web UI (it will ignore ical*url*overrides).
        :param pulumi.Input[str] ical_url_overrides: The URL of external iCal calendar which override primary events.
        :param pulumi.Input[str] ical_url_primary: The URL of the external calendar iCal file.
        :param pulumi.Input[str] name: The schedule's name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] shifts: The list of ID's of on-call shifts.
        :param pulumi.Input[Union['ScheduleSlackArgs', 'ScheduleSlackArgsDict']] slack: The Slack-specific settings for a schedule.
        :param pulumi.Input[str] team_id: The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        :param pulumi.Input[str] time_zone: The schedule's time zone.
        :param pulumi.Input[str] type: The schedule's type. Valid values are `ical`, `calendar`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScheduleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/schedules/)

        ## Import

        ```sh
        $ pulumi import grafana:onCall/schedule:Schedule name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param ScheduleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScheduleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_web_overrides: Optional[pulumi.Input[bool]] = None,
                 ical_url_overrides: Optional[pulumi.Input[str]] = None,
                 ical_url_primary: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 shifts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 slack: Optional[pulumi.Input[Union['ScheduleSlackArgs', 'ScheduleSlackArgsDict']]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 time_zone: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScheduleArgs.__new__(ScheduleArgs)

            __props__.__dict__["enable_web_overrides"] = enable_web_overrides
            __props__.__dict__["ical_url_overrides"] = ical_url_overrides
            __props__.__dict__["ical_url_primary"] = ical_url_primary
            __props__.__dict__["name"] = name
            __props__.__dict__["shifts"] = shifts
            __props__.__dict__["slack"] = slack
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["time_zone"] = time_zone
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/oncallSchedule:OncallSchedule")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Schedule, __self__).__init__(
            'grafana:onCall/schedule:Schedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enable_web_overrides: Optional[pulumi.Input[bool]] = None,
            ical_url_overrides: Optional[pulumi.Input[str]] = None,
            ical_url_primary: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            shifts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            slack: Optional[pulumi.Input[Union['ScheduleSlackArgs', 'ScheduleSlackArgsDict']]] = None,
            team_id: Optional[pulumi.Input[str]] = None,
            time_zone: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'Schedule':
        """
        Get an existing Schedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_web_overrides: Enable overrides via web UI (it will ignore ical*url*overrides).
        :param pulumi.Input[str] ical_url_overrides: The URL of external iCal calendar which override primary events.
        :param pulumi.Input[str] ical_url_primary: The URL of the external calendar iCal file.
        :param pulumi.Input[str] name: The schedule's name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] shifts: The list of ID's of on-call shifts.
        :param pulumi.Input[Union['ScheduleSlackArgs', 'ScheduleSlackArgsDict']] slack: The Slack-specific settings for a schedule.
        :param pulumi.Input[str] team_id: The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        :param pulumi.Input[str] time_zone: The schedule's time zone.
        :param pulumi.Input[str] type: The schedule's type. Valid values are `ical`, `calendar`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScheduleState.__new__(_ScheduleState)

        __props__.__dict__["enable_web_overrides"] = enable_web_overrides
        __props__.__dict__["ical_url_overrides"] = ical_url_overrides
        __props__.__dict__["ical_url_primary"] = ical_url_primary
        __props__.__dict__["name"] = name
        __props__.__dict__["shifts"] = shifts
        __props__.__dict__["slack"] = slack
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["time_zone"] = time_zone
        __props__.__dict__["type"] = type
        return Schedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enableWebOverrides")
    def enable_web_overrides(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable overrides via web UI (it will ignore ical*url*overrides).
        """
        return pulumi.get(self, "enable_web_overrides")

    @property
    @pulumi.getter(name="icalUrlOverrides")
    def ical_url_overrides(self) -> pulumi.Output[Optional[str]]:
        """
        The URL of external iCal calendar which override primary events.
        """
        return pulumi.get(self, "ical_url_overrides")

    @property
    @pulumi.getter(name="icalUrlPrimary")
    def ical_url_primary(self) -> pulumi.Output[Optional[str]]:
        """
        The URL of the external calendar iCal file.
        """
        return pulumi.get(self, "ical_url_primary")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The schedule's name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def shifts(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of ID's of on-call shifts.
        """
        return pulumi.get(self, "shifts")

    @property
    @pulumi.getter
    def slack(self) -> pulumi.Output[Optional['outputs.ScheduleSlack']]:
        """
        The Slack-specific settings for a schedule.
        """
        return pulumi.get(self, "slack")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the OnCall team. To get one, create a team in Grafana, and navigate to the OnCall plugin (to sync the team with OnCall). You can then get the ID using the `on_call_get_team` datasource.
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[Optional[str]]:
        """
        The schedule's time zone.
        """
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The schedule's type. Valid values are `ical`, `calendar`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['LibraryPanelArgs', 'LibraryPanel']

@pulumi.input_type
class LibraryPanelArgs:
    def __init__(__self__, *,
                 model_json: pulumi.Input[str],
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LibraryPanel resource.
        :param pulumi.Input[str] model_json: The JSON model for the library panel.
        :param pulumi.Input[str] folder_uid: Unique ID (UID) of the folder containing the library panel.
        :param pulumi.Input[str] name: Name of the library panel.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] uid: The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        """
        pulumi.set(__self__, "model_json", model_json)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter(name="modelJson")
    def model_json(self) -> pulumi.Input[str]:
        """
        The JSON model for the library panel.
        """
        return pulumi.get(self, "model_json")

    @model_json.setter
    def model_json(self, value: pulumi.Input[str]):
        pulumi.set(self, "model_json", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique ID (UID) of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the library panel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)


@pulumi.input_type
class _LibraryPanelState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[str]] = None,
                 dashboard_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 folder_name: Optional[pulumi.Input[str]] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 model_json: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 panel_id: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 updated: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering LibraryPanel resources.
        :param pulumi.Input[str] created: Timestamp when the library panel was created.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] dashboard_ids: Numerical IDs of Grafana dashboards containing the library panel.
        :param pulumi.Input[str] description: Description of the library panel.
        :param pulumi.Input[str] folder_name: Name of the folder containing the library panel.
        :param pulumi.Input[str] folder_uid: Unique ID (UID) of the folder containing the library panel.
        :param pulumi.Input[str] model_json: The JSON model for the library panel.
        :param pulumi.Input[str] name: Name of the library panel.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The numeric ID of the library panel computed by Grafana.
        :param pulumi.Input[str] type: Type of the library panel (eg. text).
        :param pulumi.Input[str] uid: The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        :param pulumi.Input[str] updated: Timestamp when the library panel was last modified.
        :param pulumi.Input[int] version: Version of the library panel.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if dashboard_ids is not None:
            pulumi.set(__self__, "dashboard_ids", dashboard_ids)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if folder_name is not None:
            pulumi.set(__self__, "folder_name", folder_name)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if model_json is not None:
            pulumi.set(__self__, "model_json", model_json)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if panel_id is not None:
            pulumi.set(__self__, "panel_id", panel_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp when the library panel was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created", value)

    @property
    @pulumi.getter(name="dashboardIds")
    def dashboard_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        Numerical IDs of Grafana dashboards containing the library panel.
        """
        return pulumi.get(self, "dashboard_ids")

    @dashboard_ids.setter
    def dashboard_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "dashboard_ids", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the library panel.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_name")

    @folder_name.setter
    def folder_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_name", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique ID (UID) of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter(name="modelJson")
    def model_json(self) -> Optional[pulumi.Input[str]]:
        """
        The JSON model for the library panel.
        """
        return pulumi.get(self, "model_json")

    @model_json.setter
    def model_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "model_json", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the library panel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> Optional[pulumi.Input[int]]:
        """
        The numeric ID of the library panel computed by Grafana.
        """
        return pulumi.get(self, "panel_id")

    @panel_id.setter
    def panel_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "panel_id", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the library panel (eg. text).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp when the library panel was last modified.
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[int]]:
        """
        Version of the library panel.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "version", value)


warnings.warn("""grafana.index/librarypanel.LibraryPanel has been deprecated in favor of grafana.oss/librarypanel.LibraryPanel""", DeprecationWarning)


class LibraryPanel(pulumi.CustomResource):
    warnings.warn("""grafana.index/librarypanel.LibraryPanel has been deprecated in favor of grafana.oss/librarypanel.LibraryPanel""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 model_json: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages Grafana library panels.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/build-dashboards/manage-library-panels/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/library_element/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.oss.LibraryPanel("test",
            name="panel",
            model_json=json.dumps({
                "gridPos": {
                    "x": 0,
                    "y": 0,
                    "h": 10,
                    "w": 10,
                },
                "title": "panel",
                "type": "text",
                "version": 0,
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/libraryPanel:LibraryPanel name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/libraryPanel:LibraryPanel name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] folder_uid: Unique ID (UID) of the folder containing the library panel.
        :param pulumi.Input[str] model_json: The JSON model for the library panel.
        :param pulumi.Input[str] name: Name of the library panel.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] uid: The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LibraryPanelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana library panels.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/build-dashboards/manage-library-panels/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/library_element/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.oss.LibraryPanel("test",
            name="panel",
            model_json=json.dumps({
                "gridPos": {
                    "x": 0,
                    "y": 0,
                    "h": 10,
                    "w": 10,
                },
                "title": "panel",
                "type": "text",
                "version": 0,
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/libraryPanel:LibraryPanel name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/libraryPanel:LibraryPanel name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param LibraryPanelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LibraryPanelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 model_json: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""LibraryPanel is deprecated: grafana.index/librarypanel.LibraryPanel has been deprecated in favor of grafana.oss/librarypanel.LibraryPanel""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LibraryPanelArgs.__new__(LibraryPanelArgs)

            __props__.__dict__["folder_uid"] = folder_uid
            if model_json is None and not opts.urn:
                raise TypeError("Missing required property 'model_json'")
            __props__.__dict__["model_json"] = model_json
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["uid"] = uid
            __props__.__dict__["created"] = None
            __props__.__dict__["dashboard_ids"] = None
            __props__.__dict__["description"] = None
            __props__.__dict__["folder_name"] = None
            __props__.__dict__["panel_id"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated"] = None
            __props__.__dict__["version"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/libraryPanel:LibraryPanel")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(LibraryPanel, __self__).__init__(
            'grafana:index/libraryPanel:LibraryPanel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[str]] = None,
            dashboard_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            folder_name: Optional[pulumi.Input[str]] = None,
            folder_uid: Optional[pulumi.Input[str]] = None,
            model_json: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            panel_id: Optional[pulumi.Input[int]] = None,
            type: Optional[pulumi.Input[str]] = None,
            uid: Optional[pulumi.Input[str]] = None,
            updated: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[int]] = None) -> 'LibraryPanel':
        """
        Get an existing LibraryPanel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created: Timestamp when the library panel was created.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] dashboard_ids: Numerical IDs of Grafana dashboards containing the library panel.
        :param pulumi.Input[str] description: Description of the library panel.
        :param pulumi.Input[str] folder_name: Name of the folder containing the library panel.
        :param pulumi.Input[str] folder_uid: Unique ID (UID) of the folder containing the library panel.
        :param pulumi.Input[str] model_json: The JSON model for the library panel.
        :param pulumi.Input[str] name: Name of the library panel.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The numeric ID of the library panel computed by Grafana.
        :param pulumi.Input[str] type: Type of the library panel (eg. text).
        :param pulumi.Input[str] uid: The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        :param pulumi.Input[str] updated: Timestamp when the library panel was last modified.
        :param pulumi.Input[int] version: Version of the library panel.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LibraryPanelState.__new__(_LibraryPanelState)

        __props__.__dict__["created"] = created
        __props__.__dict__["dashboard_ids"] = dashboard_ids
        __props__.__dict__["description"] = description
        __props__.__dict__["folder_name"] = folder_name
        __props__.__dict__["folder_uid"] = folder_uid
        __props__.__dict__["model_json"] = model_json
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["panel_id"] = panel_id
        __props__.__dict__["type"] = type
        __props__.__dict__["uid"] = uid
        __props__.__dict__["updated"] = updated
        __props__.__dict__["version"] = version
        return LibraryPanel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def created(self) -> pulumi.Output[str]:
        """
        Timestamp when the library panel was created.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter(name="dashboardIds")
    def dashboard_ids(self) -> pulumi.Output[Sequence[int]]:
        """
        Numerical IDs of Grafana dashboards containing the library panel.
        """
        return pulumi.get(self, "dashboard_ids")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the library panel.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> pulumi.Output[str]:
        """
        Name of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_name")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> pulumi.Output[Optional[str]]:
        """
        Unique ID (UID) of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter(name="modelJson")
    def model_json(self) -> pulumi.Output[str]:
        """
        The JSON model for the library panel.
        """
        return pulumi.get(self, "model_json")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the library panel.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> pulumi.Output[int]:
        """
        The numeric ID of the library panel computed by Grafana.
        """
        return pulumi.get(self, "panel_id")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Type of the library panel (eg. text).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[str]:
        """
        The unique identifier (UID) of a library panel uniquely identifies library panels between multiple Grafana installs. It’s automatically generated unless you specify it during library panel creation.The UID provides consistent URLs for accessing library panels and when syncing library panels between multiple Grafana installs.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def updated(self) -> pulumi.Output[str]:
        """
        Timestamp when the library panel was last modified.
        """
        return pulumi.get(self, "updated")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[int]:
        """
        Version of the library panel.
        """
        return pulumi.get(self, "version")

